@@ -236,7 +236,7 @@ _INFO = logging.INFO
 _DEBUG = logging.DEBUG
 _TRACE = logging.DEBUG - 5
 
-_Translation: dict = {}
+_Translation:dict = {}
 
 
 class _LogP():
@@ -298,6 +298,10 @@ class _LogP():
         self.__LogServer.Join(2)
         self.__LogServer.Kill()
 
+    def PollRestart(self) -> None:
+        """Prüfe ob der Logserver neu gestartet werden muss"""
+        self.__LogServer.PollRestart()
+
     def _PrintInitTranslation(self):
         print(pprint.pformat(self._InitTranslation, indent=4))
 
@@ -1160,10 +1164,13 @@ class _LogP():
             for k in self._InitTranslation.keys():                   # pylint: disable=C0201
                 try:
                     w = translation[k]
+                    if not isinstance(w, str):
+                        self._Translation[k] = self._InitTranslation[k]
+                    else:
+                        self._Translation[k] = w
                 except KeyError:
                     self._Translation[k] = self._InitTranslation[k]
-                if not isinstance(w, str):
-                    self._Translation[k] = self._InitTranslation[k]
+
 
         if not NoReset:
             for handler in logging.root.handlers[:]:
